# Sage version information for Python scripts
# This file is auto-generated by the sage-update-version script, do not edit!
version = '10.3.rc4'
date = '2024-03-17'
banner = 'SageMath version 10.3.rc4, Release Date: 2024-03-17'
